Test Implicit Locators
open | ../tests/html/test_locators.html |
verifyText | id1 | this is the first element
verifyAttribute | id1@class | a1
verifyText | name1 | this is the second element
verifyAttribute | name1@class | a2
verifyText | document.links[1] | this is the second element
verifyAttribute | document.links[1]@class | a2
verifyAttribute | //img[contains(@src, 'banner.gif')]/@alt | banner
verifyText | //body/a[2] | this is the second element